==> kubernetes-model-core-5.2.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/ResourceQuotaListFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ResourceQuotaListFluent<A extends ResourceQuotaListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ResourceQuota item);
    public A setToItems(int index,ResourceQuota item);
    public A addToItems(ResourceQuota... items);
    public A addAllToItems(Collection<ResourceQuota> items);
    public A removeFromItems(ResourceQuota... items);
    public A removeAllFromItems(Collection<ResourceQuota> items);
    public A removeMatchingFromItems(Predicate<ResourceQuotaBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ResourceQuota> getItems();
    public List<ResourceQuota> buildItems();
    public ResourceQuota buildItem(int index);
    public ResourceQuota buildFirstItem();
    public ResourceQuota buildLastItem();
    public ResourceQuota buildMatchingItem(Predicate<ResourceQuotaBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ResourceQuotaBuilder> predicate);
    public A withItems(List<ResourceQuota> items);
    public A withItems(ResourceQuota... items);
    public Boolean hasItems();
    public ResourceQuotaListFluent.ItemsNested<A> addNewItem();
    public ResourceQuotaListFluent.ItemsNested<A> addNewItemLike(ResourceQuota item);
    public ResourceQuotaListFluent.ItemsNested<A> setNewItemLike(int index,ResourceQuota item);
    public ResourceQuotaListFluent.ItemsNested<A> editItem(int index);
    public ResourceQuotaListFluent.ItemsNested<A> editFirstItem();
    public ResourceQuotaListFluent.ItemsNested<A> editLastItem();
    public ResourceQuotaListFluent.ItemsNested<A> editMatchingItem(Predicate<ResourceQuotaBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata();
    public ListMeta buildMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public ResourceQuotaListFluent.MetadataNested<A> withNewMetadata();
    public ResourceQuotaListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public ResourceQuotaListFluent.MetadataNested<A> editMetadata();
    public ResourceQuotaListFluent.MetadataNested<A> editOrNewMetadata();
    public ResourceQuotaListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceQuotaFluent<ResourceQuotaListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<ResourceQuotaListFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


}

==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/ResourceQuotaListFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ResourceQuotaListFluent<A extends ResourceQuotaListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,ResourceQuota item);
    public A setToItems(int index,ResourceQuota item);
    public A addToItems(ResourceQuota... items);
    public A addAllToItems(Collection<ResourceQuota> items);
    public A removeFromItems(ResourceQuota... items);
    public A removeAllFromItems(Collection<ResourceQuota> items);
    public A removeMatchingFromItems(Predicate<ResourceQuotaBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ResourceQuota> getItems();
    public List<ResourceQuota> buildItems();
    public ResourceQuota buildItem(int index);
    public ResourceQuota buildFirstItem();
    public ResourceQuota buildLastItem();
    public ResourceQuota buildMatchingItem(Predicate<ResourceQuotaBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ResourceQuotaBuilder> predicate);
    public A withItems(List<ResourceQuota> items);
    public A withItems(ResourceQuota... items);
    public Boolean hasItems();
    public ResourceQuotaListFluent.ItemsNested<A> addNewItem();
    public ResourceQuotaListFluent.ItemsNested<A> addNewItemLike(ResourceQuota item);
    public ResourceQuotaListFluent.ItemsNested<A> setNewItemLike(int index,ResourceQuota item);
    public ResourceQuotaListFluent.ItemsNested<A> editItem(int index);
    public ResourceQuotaListFluent.ItemsNested<A> editFirstItem();
    public ResourceQuotaListFluent.ItemsNested<A> editLastItem();
    public ResourceQuotaListFluent.ItemsNested<A> editMatchingItem(Predicate<ResourceQuotaBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata();
    public ListMeta buildMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public ResourceQuotaListFluent.MetadataNested<A> withNewMetadata();
    public ResourceQuotaListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public ResourceQuotaListFluent.MetadataNested<A> editMetadata();
    public ResourceQuotaListFluent.MetadataNested<A> editOrNewMetadata();
    public ResourceQuotaListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceQuotaFluent<ResourceQuotaListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<ResourceQuotaListFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


}
